"""
Greeum - 다국어 지원 LLM 독립적인 기억 관리 시스템

This package contains independent modules to provide a human-like 
memory system for Large Language Models.
"""

__version__ = "0.5.2"

# Core components imports
try:
    from .text_utils import process_user_input, extract_keywords_from_text, extract_tags_from_text, compute_text_importance, convert_numpy_types
except ImportError:
    pass

# 편의를 위한 별명
try:
    process_text = process_user_input
except NameError:
    pass

try:
    from .database_manager import DatabaseManager
except ImportError:
    pass

try:
    from .embedding_models import (
        SimpleEmbeddingModel, SentenceTransformerEmbedding, OpenAIEmbedding,
        EmbeddingRegistry, get_embedding, register_embedding_model,
        init_sentence_transformer, init_openai
    )
except ImportError:
    pass

try:
    from .temporal_reasoner import TemporalReasoner, evaluate_temporal_query
except ImportError:
    pass

try:
    from .memory_evolution import MemoryEvolutionManager
except ImportError:
    pass

try:
    from .knowledge_graph import KnowledgeGraphManager
except ImportError:
    pass

# Original components (for compatibility)
try:
    from .block_manager import BlockManager
except ImportError:
    pass

try:
    from .stm_manager import STMManager
except ImportError:
    pass

try:
    from .cache_manager import CacheManager
except ImportError:
    pass

try:
    from .prompt_wrapper import PromptWrapper
except ImportError:
    pass

# numpy 타입 변환 유틸리티를 최상위로 노출
try:
    from .text_utils import convert_numpy_types
except ImportError:
    pass

try:
    from .client import (
        MemoryClient, SimplifiedMemoryClient, 
        ClientError, ConnectionFailedError, RequestTimeoutError, APIError
    )
except ImportError:
    pass

__all__ = [
    "__version__",
    # Core components
    "BlockManager",
    "STMManager",
    "CacheManager",
    "PromptWrapper",
    
    # Database management
    "DatabaseManager",
    
    # Embedding models
    "EmbeddingModel",
    "SimpleEmbeddingModel", 
    "SentenceTransformerEmbedding",
    "OpenAIEmbedding",
    "embedding_registry",
    "get_embedding",
    "register_embedding_model",
    "init_sentence_transformer",
    "init_openai",
    
    # Temporal reasoning
    "TemporalReasoner",
    "evaluate_temporal_query",
    
    # Memory evolution
    "MemoryEvolutionManager",
    
    # Knowledge graph
    "KnowledgeGraphManager",

    # Text utilities
    "process_user_input",
    "process_text",
    "extract_keywords_from_text",
    "extract_tags_from_text",
    "compute_text_importance",
    "convert_numpy_types",
    
    # Client and exceptions
    "MemoryClient",
    "SimplifiedMemoryClient",
    "ClientError",
    "ConnectionFailedError",
    "RequestTimeoutError",
    "APIError"
] 